@@ -19,7 +19,7 @@ require Exporter;
 
 @EXPORT_OK = ( @{ $EXPORT_TAGS{all} } );
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 =head1 NAME
 
@@ -43,20 +43,28 @@ contains trivial but commonly-used functionality for hashes.
 Returns a hash containing the (key, value) pair for every
 key in LIST.
 
+If no C<< LIST >> is given, all keys are assumed as C<< LIST >>.
+
 =head2 C<slice_def> HASHREF[, LIST]
 
 As C<slice>, but only includes keys whose values are
 defined.
 
+If no C<< LIST >> is given, all keys are assumed as C<< LIST >>.
+
 =head2 C<slice_exists> HASHREF[, LIST]
 
 As C<slice> but only includes keys which exist in the
 hashref.
 
+If no C<< LIST >> is given, all keys are assumed as C<< LIST >>.
+
 =head2 C<slice_grep> BLOCK, HASHREF[, LIST]
 
 As C<slice>, with an arbitrary condition.
 
+If no C<< LIST >> is given, all keys are assumed as C<< LIST >>.
+
 Unlike C<grep>, the condition is not given aliases to
 elements of anything.  Instead, C<< %_ >> is set to the
 contents of the hashref, to avoid accidentally
@@ -66,8 +74,6 @@ scope.
 
 =cut
 
-sub slice_grep (&@);
-
 sub slice
 {
     my ( $href, @list ) = @_;
@@ -244,7 +250,7 @@ L<http://search.cpan.org/dist/Hash-MoreUtils/>
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2005 Hans Dieter Pearcey, all rights reserved.
-Copyright 2010 Jens Rehsack
+Copyright 2010-2013 Jens Rehsack
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
